@@ -32,6 +32,7 @@ from google.cloud import bigquery
 from google.cloud.bigquery import job
 from google.cloud.bigquery import table
 from google.cloud.bigquery.magics import magics
+from google.cloud.bigquery.retry import DEFAULT_TIMEOUT
 from tests.unit.helpers import make_connection
 from test_utils.imports import maybe_fail_import
 
@@ -185,7 +186,7 @@ def test_context_with_default_connection():
         method="POST",
         path="/projects/project-from-env/jobs",
         data=mock.ANY,
-        timeout=None,
+        timeout=DEFAULT_TIMEOUT,
     )
     query_results_call = mock.call(
         method="GET",
@@ -249,7 +250,7 @@ def test_context_with_custom_connection():
         method="POST",
         path="/projects/project-from-env/jobs",
         data=mock.ANY,
-        timeout=None,
+        timeout=DEFAULT_TIMEOUT,
     )
     query_results_call = mock.call(
         method="GET",
@@ -660,7 +661,9 @@ def test_bigquery_magic_with_bqstorage_from_argument(monkeypatch):
     assert client_info.user_agent == "ipython-" + IPython.__version__
 
     query_job_mock.to_dataframe.assert_called_once_with(
-        bqstorage_client=bqstorage_instance_mock, progress_bar_type="tqdm"
+        bqstorage_client=bqstorage_instance_mock,
+        create_bqstorage_client=mock.ANY,
+        progress_bar_type="tqdm",
     )
 
     assert isinstance(return_value, pandas.DataFrame)
@@ -703,7 +706,9 @@ def test_bigquery_magic_with_rest_client_requested(monkeypatch):
 
         bqstorage_mock.assert_not_called()
         query_job_mock.to_dataframe.assert_called_once_with(
-            bqstorage_client=None, progress_bar_type="tqdm"
+            bqstorage_client=None,
+            create_bqstorage_client=False,
+            progress_bar_type="tqdm",
         )
 
     assert isinstance(return_value, pandas.DataFrame)
@@ -757,7 +762,12 @@ def test_bigquery_magic_w_max_results_valid_calls_queryjob_result():
         client_query_mock.return_value = query_job_mock
         ip.run_cell_magic("bigquery", "--max_results=5", sql)
 
-        query_job_mock.result.assert_called_with(max_results=5)
+    query_job_mock.result.assert_called_with(max_results=5)
+    query_job_mock.result.return_value.to_dataframe.assert_called_once_with(
+        bqstorage_client=None,
+        create_bqstorage_client=False,
+        progress_bar_type=mock.ANY,
+    )
 
 
 @pytest.mark.usefixtures("ipython_interactive")
@@ -929,7 +939,7 @@ def test_bigquery_magic_w_table_id_and_bqstorage_client():
 
         ip.run_cell_magic("bigquery", "--max_results=5", table_id)
         row_iterator_mock.to_dataframe.assert_called_once_with(
-            bqstorage_client=bqstorage_instance_mock
+            bqstorage_client=bqstorage_instance_mock, create_bqstorage_client=mock.ANY,
         )
 
 
@@ -1246,7 +1256,9 @@ def test_bigquery_magic_w_progress_bar_type_w_context_setter(monkeypatch):
 
         bqstorage_mock.assert_not_called()
         query_job_mock.to_dataframe.assert_called_once_with(
-            bqstorage_client=None, progress_bar_type=magics.context.progress_bar_type
+            bqstorage_client=None,
+            create_bqstorage_client=False,
+            progress_bar_type=magics.context.progress_bar_type,
         )
 
     assert isinstance(return_value, pandas.DataFrame)
